# Free AIML Rule Sets

This is a collection of open-sourced AIML (Artificial Intelligence Markup 
Language) rule sets, for use with any compatible AIML conversational engine.
The files have been repackaged into a single repo for easy download and
installation. I plan to eventually distribute this on the Python Package 
Index to make it installable with Python's package installer, pip, making
it easily available for use with [AIML 
Bot](https://github.com/hosford42/aiml_bot).

## GNU General Public License

All files are released under the GNU General Public License. The included 
AIML files are (c) ALICE A.I. Foundation, Inc. I have taken care to 
exclude any files that did not specifically contain a copyright & license 
header provided by the original author. Any additional files that are not 
marked with a copyright header of their own are (c) Aaron Hosford.

## Included AIML Sets 

* [Free A.L.I.C.E. AIML Set](
  https://code.google.com/archive/p/aiml-en-us-foundation-alice/downloads)
  (ALICE)
* [Square Bear's AIML files](http://www.square-bear.co.uk/aiml/) 
  (Mitsuku)
* [Standard AIML Set](https://github.com/cdwfs/pyaiml/tree/master/standard)
  (PyAIML)
